==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/sl.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'sl', {
	button: {
		title: 'Lastnosti gumba',
		text: 'Besedilo (Vrednost)',
		type: 'Tip',
		typeBtn: 'Gumb',
		typeSbm: 'Potrdi',
		typeRst: 'Ponastavi'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Lastnosti potrditvenega polja',
		radioTitle: 'Lastnosti izbirnega polja',
		value: 'Vrednost',
		selected: 'Izbrano'
	},
	form: {
		title: 'Lastnosti obrazca',
		menu: 'Lastnosti obrazca',
		action: 'Akcija',
		method: 'Metoda',
		encoding: 'Kodiranje znakov'
	},
	hidden: {
		title: 'Lastnosti skritega polja',
		name: 'Ime',
		value: 'Vrednost'
	},
	select: {
		title: 'Lastnosti spustnega seznama',
		selectInfo: 'Podatki',
		opAvail: 'Razpoložljive izbire',
		value: 'Vrednost',
		size: 'Velikost',
		lines: 'vrstic',
		chkMulti: 'Dovoli izbor večih vrstic',
		opText: 'Besedilo',
		opValue: 'Vrednost',
		btnAdd: 'Dodaj',
		btnModify: 'Spremeni',
		btnUp: 'Gor',
		btnDown: 'Dol',
		btnSetValue: 'Postavi kot privzeto izbiro',
		btnDelete: 'Izbriši'
	},
	textarea: {
		title: 'Lastnosti vnosnega območja',
		cols: 'Stolpcev',
		rows: 'Vrstic'
	},
	textfield: {
		title: 'Lastnosti vnosnega polja',
		name: 'Ime',
		value: 'Vrednost',
		charWidth: 'Dolžina',
		maxChars: 'Največje število znakov',
		type: 'Tip',
		typeText: 'Besedilo',
		typePass: 'Geslo',
		typeEmail: 'E-pošta',
		typeSearch: 'Iskanje',
		typeTel: 'Telefonska Številka',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/sl.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'sl', {
	button: {
		title: 'Lastnosti gumba',
		text: 'Besedilo (Vrednost)',
		type: 'Tip',
		typeBtn: 'Gumb',
		typeSbm: 'Potrdi',
		typeRst: 'Ponastavi'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Lastnosti potrditvenega polja',
		radioTitle: 'Lastnosti izbirnega polja',
		value: 'Vrednost',
		selected: 'Izbrano',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Lastnosti obrazca',
		menu: 'Lastnosti obrazca',
		action: 'Akcija',
		method: 'Metoda',
		encoding: 'Kodiranje znakov'
	},
	hidden: {
		title: 'Lastnosti skritega polja',
		name: 'Ime',
		value: 'Vrednost'
	},
	select: {
		title: 'Lastnosti spustnega seznama',
		selectInfo: 'Podatki',
		opAvail: 'Razpoložljive izbire',
		value: 'Vrednost',
		size: 'Velikost',
		lines: 'vrstic',
		chkMulti: 'Dovoli izbor večih vrstic',
		required: 'Required', // MISSING
		opText: 'Besedilo',
		opValue: 'Vrednost',
		btnAdd: 'Dodaj',
		btnModify: 'Spremeni',
		btnUp: 'Gor',
		btnDown: 'Dol',
		btnSetValue: 'Postavi kot privzeto izbiro',
		btnDelete: 'Izbriši'
	},
	textarea: {
		title: 'Lastnosti vnosnega območja',
		cols: 'Stolpcev',
		rows: 'Vrstic'
	},
	textfield: {
		title: 'Lastnosti vnosnega polja',
		name: 'Ime',
		value: 'Vrednost',
		charWidth: 'Dolžina',
		maxChars: 'Največje število znakov',
		required: 'Required', // MISSING
		type: 'Tip',
		typeText: 'Besedilo',
		typePass: 'Geslo',
		typeEmail: 'E-pošta',
		typeSearch: 'Iskanje',
		typeTel: 'Telefonska Številka',
		typeUrl: 'URL'
	}
} );
